"""
EnMAP-Box Workshop 2021
Benjamin Jakimow

The following example shows you how to create and display a GUI with help of Qt and QGIS
"""
from enmapbox.testing import start_app
import enmapboxtestdata
from qgis.core import QgsRasterLayer, QgsProject
from qgis.gui import QgsMapCanvas
from PyQt5.QtGui import QIcon

app = start_app()

# create a QgsMapCanvas, which can display geospatial data
# see https://qgis.org/pyqgis/3.18/gui/QgsMapCanvas.html for details
canvas = QgsMapCanvas()

canvas.setWindowTitle('Hello QGIS GUI')

# Add an icon. You can use the EnMAP-Box -> Tools -> Developers -> Resource Browser to copy the
# resource path of all icons available in a running QGIS environment
canvas.setWindowIcon(QIcon(':/enmapbox/gui/ui/icons/enmapbox.svg'))

# create two QgsRasterLayers
layerEnMAP = QgsRasterLayer(enmapboxtestdata.enmap)
path = 'type=xyz&url=https://tile.openstreetmap.org/%7Bz%7D/%7Bx%7D/%7By%7D.png&zmax=19&zmin=0'
layerOSM = QgsRasterLayer(path, 'OSM', 'WMS')

layers = [layerEnMAP, layerOSM]
for l in layers:
    assert layerEnMAP.isValid()

# before we can display a raster / vector layer, we need to register them in the QgsProject
QgsProject.instance().addMapLayers(layers)

# Now add both layers to the QgsMapCanvas
canvas.setLayers(layers)
canvas.setDestinationCrs(layerEnMAP.crs())
canvas.setExtent(layerEnMAP.extent())

canvas.show()

# this line starts the GUI thread, which repeatedly waits for user interaction (mouse & keyboard actions etc.)
# it will be stopped when you close the canvas widget
app.exec_()