"""
EnMAP-Box Workshop 2021
Benjamin Jakimow

How to use EnMAP-Box QgsProcessingAlgorithms from python

Before, please
1. clone the EnMAP-Box repository and add it as source folder to your PyCharm project / PYTHONPATH
2. run python <enmapbox repository>/scripts/setup_repository.py to download some testdata that is
   required by the 'enmapbox:CreateTestClassificationMap' QgsProcessingAlgorithm
"""
from enmapbox.testing import start_app
from qgis.core import QgsProcessingFeedback, QgsProcessingContext, QgsApplication, QgsProcessingAlgorithm, QgsRasterLayer

# this initialises a QgsApplication and some of its sub-components
start_app()

def onProgress(progress: float):
    print('{:0.2f} %'.format(progress))

feedback = QgsProcessingFeedback()
feedback.progressChanged.connect(onProgress)

context = QgsProcessingContext()
context.setFeedback(feedback)

# print available QgsProcessingAlgorithms
for a in QgsApplication.processingRegistry().algorithms():
    print(a.id())

id = 'enmapbox:CreateTestClassificationMap'
alg: QgsProcessingAlgorithm = QgsApplication.processingRegistry().algorithmById(id)
assert isinstance(alg, QgsProcessingAlgorithm)

parameters = {'outClassification': 'classexample.tif'}
assert alg.prepareAlgorithm(parameters, context, feedback), feedback.textLog()
result = alg.processAlgorithm(parameters, context, feedback)

lyr = QgsRasterLayer(result['outClassification'])
assert lyr.isValid()
